{ config, pkgs, inputs, lib, nixpkgs-nixos-unstable-and-unfree, ... }: {
  networking.hostName = "foureighty";

  imports = [
    inputs.nixos-hardware.nixosModules.lenovo-thinkpad-t480
    ./custom-kernel.nix
    ./hardware-configuration.nix
    ./tailscale-foureighty.nix
    ./thermal.nix
    ../../backups.nix
    ../../boot.nix
    ../../common.nix
    ../../distributed-builds.nix
    ../../git
    ../../gui
    ../../i3
    ../../libvirt.nix
    ../../mercurial
    ../../tailscale.nix
  ];

  fileSystems."/" = { options = [ "compress=zstd" ]; };

  boot.kernelPackages = pkgs.linuxPackages_latest;
  boot.binfmt.emulatedSystems = [ "aarch64-linux" ];

  zramSwap = {
    enable = true;
    algorithm = "zstd";
    memoryPercent = 75;
  };

  time.timeZone = "Europe/London";

  virtualisation.kvmgt = {
    enable = true;
    device = "0000:00:02.0";
  };
  hardware.trackpoint.enable = true;
  services.hardware.bolt.enable = true;
  hardware.video.hidpi.enable = lib.mkDefault true;

  services.fprintd = { enable = true; };

  home-manager.users.cyryl = { ... }: {
    imports = [ ../../home-manager/programs/kitty.nix ];
    home.packages = [
      inputs.nixpkgs-nixos-unstable.legacyPackages."x86_64-linux".bisq-desktop
    ];
  };
}
